[xfdesktop-version-4.10.3+-rcfile_format]
4.10.3+=true

[/home/kylert/Desktop/AEW.Dynamite.2021.09.22.1080p.WEB.h264-HEEL.mp4]
row=2
col=25

[/home/kylert/Desktop/242505602_3144866715746736_2591173778215334938_n.jpg]
row=1
col=25

[/home/kylert/Desktop/web-server-key-pair(1).pem]
row=0
col=25

