[Settings]
ShowAllProcesses=FALSE
ShowLegend=TRUE
MorePrecision=FALSE
FullCommandLine=FALSE
ShowStatusIcon=FALSE
MonitorPaintBox=TRUE
ShowApplicationIcons=TRUE
ToolbarStyle=DEFAULT
PromptTerminateTask=TRUE
RefreshRate=2000
ColumnUID=FALSE
ColumnPID=TRUE
ColumnPPID=FALSE
ColumnState=FALSE
ColumnVSZ=FALSE
ColumnRSS=TRUE
ColumnCPU=TRUE
ColumnPriority=FALSE
SortColumn=7
SortType=1
WindowWidth=662
WindowHeight=552
HandlePosition=100
ProcessTreeView=FALSE
