[xfdesktop-version-4.10.3+-rcfile_format]
4.10.3+=true

[/home/kylert/Desktop/screenshot-www.amazon.com-2021.07.30-17_24_36.png]
row=2
col=24

[/home/kylert/Desktop/screenshot-www.google.com-2021.07.30-17_25_31.png]
row=3
col=24

[/home/kylert/Desktop/Unicomp Order.png]
row=1
col=24

[/home/kylert/Desktop/cache-3000.kdenlive]
row=4
col=24

[6647-44D2]
row=0
col=24

