favorites=xfce4-web-browser.desktop,xfce4-mail-reader.desktop,xfce4-file-manager.desktop,xfce4-terminal-emulator.desktop
recent=thunar.desktop,google-chrome.desktop,xfce-ui-settings.desktop,xfce-session-settings.desktop,xfce4-mime-settings.desktop,xfce4-notifyd-config.desktop,monodevelop.desktop,chrome-faolnafnngnfdaknnbpnkhgohbobgegn-Default.desktop,org.gnome.Evolution.desktop,insync.desktop
button-icon=/home/kylert/Downloads/58922-kernel-logo-arch-linux-png-download-free_64x64.ico
button-single-row=false
show-button-title=true
show-button-icon=true
launcher-show-name=true
launcher-show-description=true
launcher-show-tooltip=true
item-icon-size=3
hover-switch-category=false
category-show-name=true
category-icon-size=0
sort-categories=true
view-mode=1
default-category=1
recent-items-max=10
favorites-in-recent=true
position-search-alternate=true
position-commands-alternate=false
position-categories-alternate=false
stay-on-focus-out=false
confirm-session-command=true
menu-width=879
menu-height=537
menu-opacity=50
command-settings=xfce4-settings-manager
show-command-settings=true
command-lockscreen=xflock4
show-command-lockscreen=true
command-switchuser=gdmflexiserver
show-command-switchuser=false
command-logoutuser=xfce4-session-logout --logout --fast
show-command-logoutuser=false
command-restart=xfce4-session-logout --reboot --fast
show-command-restart=false
command-shutdown=xfce4-session-logout --halt --fast
show-command-shutdown=false
command-suspend=xfce4-session-logout --suspend
show-command-suspend=false
command-hibernate=xfce4-session-logout --hibernate
show-command-hibernate=false
command-logout=xfce4-session-logout
show-command-logout=true
command-menueditor=menulibre
show-command-menueditor=true
command-profile=sh -c 'env XDG_CURRENT_DESKTOP=GNOME GTK_CSD=1 gnome-control-center'
show-command-profile=true
search-actions=5

[action0]
name=Man Pages
pattern=#
command=exo-open --launch TerminalEmulator man %s
regex=false

[action1]
name=Web Search
pattern=?
command=exo-open --launch WebBrowser https://duckduckgo.com/?q=%u
regex=false

[action2]
name=Wikipedia
pattern=!w
command=exo-open --launch WebBrowser https://en.wikipedia.org/wiki/%u
regex=false

[action3]
name=Run in Terminal
pattern=!
command=exo-open --launch TerminalEmulator %s
regex=false

[action4]
name=Open URI
pattern=^(file|http|https):\\/\\/(.*)$
command=exo-open \\0
regex=true

